==> groups-0.3.tar.gz: publish/profiles/groups/modules/groups/groups_footer/templates/groups_footer.tpl.php <==
<!--   <ul class="footer-block-contribute">
    <li class="header">Contribute to the Groups Portal</li>
    <li><a href="https://storyboard.openstack.org/#!/project/704">Report Issues</a></li>
    <li><a href="/tips">Establish a New Group</a></li>
    <li><a href="/code-of-conduct">Code of Conduct</a></li>
  </ul> -->
  <div class="footer-block-openstack">
    <h3>OpenStack</h3>
    <ul>
      <li><a href="http://openstack.org/projects/">Projects</a></li>
      <li><a href="http://openstack.org/openstack-security/">OpenStack Security</a></li>
      <li><a href="http://openstack.org/projects/openstack-faq/">Common Questions</a></li>
      <li><a href="http://openstack.org/blog/">Blog</a></li>
    </ul>
  </div>
  <div class="footer-block-community">
    <h3>Community</h3>
    <ul>
      <li><a href="http://openstack.org/community/">User Groups</a></li>
      <li><a href="http://openstack.org/events/">Events</a></li>
      <li><a href="http://openstack.org/jobs/">Jobs</a></li>
      <li><a href="http://openstack.org/companies/">Companies</a></li>
      <li><a href="http://wiki.openstack.org/HowToContribute">Contribute</a></li>
    </ul>
  </div>
  <div class="footer-block-documentation">
    <h3>Documentation</h3>
    <ul>
      <li><a href="http://docs.openstack.org/">OpenStack Manuals</a></li>
      <li><a href="http://www.openstack.org/software/start/">Getting Started</a></li>
      <li><a href="http://api.openstack.org/">API Documentation</a></li>
      <li><a href="http://wiki.openstack.org/">Wiki</a></li>
    </ul>
  </div>
  <div class="footer-block-branding">
    <h3>Branding & Legal</h3>
    <ul>
      <li><a href="http://openstack.org/brand/">Logos &amp; Guidelines</a></li>
      <li><a href="http://openstack.org/brand/openstack-trademark-policy/">Trademark Policy</a></li>
      <li><a href="http://openstack.org/privacy/">Privacy Policy</a></li>
      <li><a href="http://wiki.openstack.org/CLA">OpenStack CLA</a></li>
    </ul>
  </div>
  <div class="footer-block-stay-in-touch">
    <h3>Stay In Touch</h3>
    <a href="https://twitter.com/OpenStack" target="_blank" class="social-icons social-icon-twitter"></a>
    <a href="https://www.facebook.com/openstack" target="_blank" class="social-icons social-icon-facebook"></a>
    <a href="https://www.linkedin.com/company/openstack" target="_blank" class="social-icons social-icon-linkedin"></a>
    <a href="https://www.youtube.com/user/OpenStackFoundation" target="_blank" class="social-icons social-icon-youtube"></a>
    <p class="fine-print">OpenStack is a trademark of OpenStack Foundation.</p>
  </div>

==> groups-0.21.tar.gz: publish/profiles/groups/modules/groups/groups_footer/templates/groups_footer.tpl.php <==
<!--   <ul class="footer-block-contribute">
    <li class="header">Contribute to the Groups Portal</li>
    <li><a href="https://storyboard.openstack.org/#!/project/704">Report Issues</a></li>
    <li><a href="/tips">Establish a New Group</a></li>
    <li><a href="/code-of-conduct">Code of Conduct</a></li>
  </ul> -->
  <div class="footer-block-openstack">
    <h3>OpenStack</h3>
    <ul>
      <li><a href="http://openstack.org/projects/">Projects</a></li>
      <li><a href="http://openstack.org/openstack-security/">OpenStack Security</a></li>
      <li><a href="http://openstack.org/projects/openstack-faq/">Common Questions</a></li>
      <li><a href="http://openstack.org/blog/">Blog</a></li>
    </ul>
  </div>
  <div class="footer-block-community">
    <h3>Community</h3>
    <ul>
      <li><a href="http://openstack.org/community/">Community</a></li>
      <li><a href="http://openstack.org/events/">Events</a></li>
      <li><a href="http://openstack.org/jobs/">Jobs</a></li>
      <li><a href="http://openstack.org/companies/">Companies</a></li>
      <li><a href="http://docs.openstack.org/infra/manual/developers.html">Contribute</a></li>
    </ul>
  </div>
  <div class="footer-block-documentation">
    <h3>Documentation</h3>
    <ul>
      <li><a href="http://docs.openstack.org/">OpenStack Manuals</a></li>
      <li><a href="http://www.openstack.org/software/start/">Getting Started</a></li>
      <li><a href="http://api.openstack.org/">API Documentation</a></li>
      <li><a href="http://wiki.openstack.org/">Wiki</a></li>
    </ul>
  </div>
  <div class="footer-block-branding">
    <h3>Branding & Legal</h3>
    <ul>
      <li><a href="http://openstack.org/brand/">Logos &amp; Guidelines</a></li>
      <li><a href="http://openstack.org/brand/openstack-trademark-policy/">Trademark Policy</a></li>
      <li><a href="http://openstack.org/privacy/">Privacy Policy</a></li>
      <li><a href="http://wiki.openstack.org/CLA">OpenStack CLA</a></li>
    </ul>
  </div>
  <div class="footer-block-stay-in-touch">
    <h3>Stay In Touch</h3>
    <a href="https://twitter.com/OpenStack" target="_blank" class="social-icons social-icon-twitter"></a>
    <a href="https://www.facebook.com/openstack" target="_blank" class="social-icons social-icon-facebook"></a>
    <a href="https://www.linkedin.com/company/openstack" target="_blank" class="social-icons social-icon-linkedin"></a>
    <a href="https://www.youtube.com/user/OpenStackFoundation" target="_blank" class="social-icons social-icon-youtube"></a>
    <p class="fine-print">OpenStack is a trademark of OpenStack Foundation.</p>
  </div>
